# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["EmailSendMonthlyDigestParams"]


class EmailSendMonthlyDigestParams(TypedDict, total=False):
    role: Literal["admin", "user"]
    """Filter by user role"""
