# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["V2ToggleFollowResponse"]


class V2ToggleFollowResponse(BaseModel):
    following: bool
