# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["V3RetrieveAllParams"]


class V3RetrieveAllParams(TypedDict, total=False):
    limit: str

    skip: str
