# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3ToggleSharingParams"]


class V3ToggleSharingParams(TypedDict, total=False):
    sharing_status: Required[Annotated[Literal["not_shared", "shared"], PropertyInfo(alias="sharingStatus")]]
