# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = [
    "OverviewRetrieveStatusResponse",
    "Translations",
    "TranslationsID",
    "TranslationsAm",
    "TranslationsAr",
    "TranslationsAz",
    "TranslationsBg",
    "TranslationsBn",
    "TranslationsCa",
    "TranslationsCs",
    "TranslationsDa",
    "TranslationsDe",
    "TranslationsEl",
    "TranslationsEn",
    "TranslationsEs",
    "TranslationsEt",
    "TranslationsFa",
    "TranslationsFi",
    "TranslationsFr",
    "TranslationsGu",
    "TranslationsHa",
    "TranslationsHe",
    "TranslationsHi",
    "TranslationsHr",
    "TranslationsHu",
    "TranslationsIt",
    "TranslationsJa",
    "TranslationsKa",
    "TranslationsKn",
    "TranslationsKo",
    "TranslationsLt",
    "TranslationsLv",
    "TranslationsMl",
    "TranslationsMr",
    "TranslationsMs",
    "TranslationsMy",
    "TranslationsNe",
    "TranslationsNl",
    "TranslationsNo",
    "TranslationsPa",
    "TranslationsPl",
    "TranslationsPt",
    "TranslationsRo",
    "TranslationsRu",
    "TranslationsSi",
    "TranslationsSk",
    "TranslationsSl",
    "TranslationsSr",
    "TranslationsSv",
    "TranslationsSw",
    "TranslationsTa",
    "TranslationsTe",
    "TranslationsTh",
    "TranslationsTl",
    "TranslationsTr",
    "TranslationsUk",
    "TranslationsUr",
    "TranslationsUz",
    "TranslationsVi",
    "TranslationsYo",
    "TranslationsZh",
]


class TranslationsID(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsAm(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsAr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsAz(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsBg(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsBn(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsCa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsCs(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsDa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsDe(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsEl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsEn(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsEs(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsEt(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsFa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsFi(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsFr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsGu(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsHa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsHe(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsHi(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsHr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsHu(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsIt(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsJa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsKa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsKn(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsKo(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsLt(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsLv(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsMl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsMr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsMs(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsMy(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsNe(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsNl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsNo(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsPa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsPl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsPt(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsRo(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsRu(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSi(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSk(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSv(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsSw(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsTa(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsTe(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsTh(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsTl(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsTr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsUk(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsUr(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsUz(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsVi(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsYo(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class TranslationsZh(BaseModel):
    error: Optional[str] = None

    requested_at: float = FieldInfo(alias="requestedAt")

    state: Literal["queued", "done", "errored"]

    updated_at: float = FieldInfo(alias="updatedAt")


class Translations(BaseModel):
    id: Optional[TranslationsID] = None

    am: Optional[TranslationsAm] = None

    ar: Optional[TranslationsAr] = None

    az: Optional[TranslationsAz] = None

    bg: Optional[TranslationsBg] = None

    bn: Optional[TranslationsBn] = None

    ca: Optional[TranslationsCa] = None

    cs: Optional[TranslationsCs] = None

    da: Optional[TranslationsDa] = None

    de: Optional[TranslationsDe] = None

    el: Optional[TranslationsEl] = None

    en: Optional[TranslationsEn] = None

    es: Optional[TranslationsEs] = None

    et: Optional[TranslationsEt] = None

    fa: Optional[TranslationsFa] = None

    fi: Optional[TranslationsFi] = None

    fr: Optional[TranslationsFr] = None

    gu: Optional[TranslationsGu] = None

    ha: Optional[TranslationsHa] = None

    he: Optional[TranslationsHe] = None

    hi: Optional[TranslationsHi] = None

    hr: Optional[TranslationsHr] = None

    hu: Optional[TranslationsHu] = None

    it: Optional[TranslationsIt] = None

    ja: Optional[TranslationsJa] = None

    ka: Optional[TranslationsKa] = None

    kn: Optional[TranslationsKn] = None

    ko: Optional[TranslationsKo] = None

    lt: Optional[TranslationsLt] = None

    lv: Optional[TranslationsLv] = None

    ml: Optional[TranslationsMl] = None

    mr: Optional[TranslationsMr] = None

    ms: Optional[TranslationsMs] = None

    my: Optional[TranslationsMy] = None

    ne: Optional[TranslationsNe] = None

    nl: Optional[TranslationsNl] = None

    no: Optional[TranslationsNo] = None

    pa: Optional[TranslationsPa] = None

    pl: Optional[TranslationsPl] = None

    pt: Optional[TranslationsPt] = None

    ro: Optional[TranslationsRo] = None

    ru: Optional[TranslationsRu] = None

    si: Optional[TranslationsSi] = None

    sk: Optional[TranslationsSk] = None

    sl: Optional[TranslationsSl] = None

    sr: Optional[TranslationsSr] = None

    sv: Optional[TranslationsSv] = None

    sw: Optional[TranslationsSw] = None

    ta: Optional[TranslationsTa] = None

    te: Optional[TranslationsTe] = None

    th: Optional[TranslationsTh] = None

    tl: Optional[TranslationsTl] = None

    tr: Optional[TranslationsTr] = None

    uk: Optional[TranslationsUk] = None

    ur: Optional[TranslationsUr] = None

    uz: Optional[TranslationsUz] = None

    vi: Optional[TranslationsVi] = None

    yo: Optional[TranslationsYo] = None

    zh: Optional[TranslationsZh] = None


class OverviewRetrieveStatusResponse(BaseModel):
    state: Literal["queued", "extracting", "generating", "done", "errored"]

    translations: Translations

    updated_at: float = FieldInfo(alias="updatedAt")
    """Milliseconds since UNIX epoch"""
