# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v3_create_params import V3CreateParams as V3CreateParams
from .v3_list_response import V3ListResponse as V3ListResponse
from .v3_create_response import V3CreateResponse as V3CreateResponse
from .v3_add_papers_params import V3AddPapersParams as V3AddPapersParams
from .v3_move_papers_params import V3MovePapersParams as V3MovePapersParams
from .v3_update_name_params import V3UpdateNameParams as V3UpdateNameParams
from .v3_add_papers_response import V3AddPapersResponse as V3AddPapersResponse
from .v3_move_papers_response import V3MovePapersResponse as V3MovePapersResponse
from .v3_remove_papers_params import V3RemovePapersParams as V3RemovePapersParams
from .v3_update_parent_params import V3UpdateParentParams as V3UpdateParentParams
from .v3_toggle_sharing_params import V3ToggleSharingParams as V3ToggleSharingParams
from .v3_toggle_sharing_response import V3ToggleSharingResponse as V3ToggleSharingResponse
