# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .lab_retrieve_response import LabRetrieveResponse as LabRetrieveResponse
