# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["V3AddPapersParams"]


class V3AddPapersParams(TypedDict, total=False):
    paper_group_ids: Annotated[SequenceNotStr[str], PropertyInfo(alias="paperGroupIds")]

    universal_ids: Annotated[SequenceNotStr[str], PropertyInfo(alias="universalIds")]
