# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_get_top_papers_params import V1GetTopPapersParams as V1GetTopPapersParams
