# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V2GetChatsParams"]


class V2GetChatsParams(TypedDict, total=False):
    folder: str

    paper_version: Annotated[str, PropertyInfo(alias="paperVersion")]

    variant: Literal["homepage", "paper", "folder"]
