# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["XMentionUpdateParams"]


class XMentionUpdateParams(TypedDict, total=False):
    dry_run: Annotated[bool, PropertyInfo(alias="dryRun")]
    """If true, only logs results without saving to database"""
