# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .email_send_weekly_digest_params import EmailSendWeeklyDigestParams as EmailSendWeeklyDigestParams
from .email_send_monthly_digest_params import EmailSendMonthlyDigestParams as EmailSendMonthlyDigestParams
