# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_generate_speech_params import V1GenerateSpeechParams as V1GenerateSpeechParams
from .v1_generate_speech_response import V1GenerateSpeechResponse as V1GenerateSpeechResponse
