# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import TypeAlias

__all__ = ["V1GetTotalUserCountResponse"]

V1GetTotalUserCountResponse: TypeAlias = float
