# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["VersionRequestAITranslationResponse"]


class VersionRequestAITranslationResponse(BaseModel):
    data: str
