# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["V3GetClaimedPapersParams"]


class V3GetClaimedPapersParams(TypedDict, total=False):
    sort: Literal["date", "liked", "citations"]
