# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["ModeratorToggleFlagsParams"]


class ModeratorToggleFlagsParams(TypedDict, total=False):
    addressed: bool

    closed: bool

    flag_addressed: Annotated[bool, PropertyInfo(alias="flagAddressed")]
