# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .email import (
    EmailResource,
    AsyncEmailResource,
    EmailResourceWithRawResponse,
    AsyncEmailResourceWithRawResponse,
    EmailResourceWithStreamingResponse,
    AsyncEmailResourceWithStreamingResponse,
)
from .preferences import (
    PreferencesResource,
    AsyncPreferencesResource,
    PreferencesResourceWithRawResponse,
    AsyncPreferencesResourceWithRawResponse,
    PreferencesResourceWithStreamingResponse,
    AsyncPreferencesResourceWithStreamingResponse,
)

__all__ = [
    "EmailResource",
    "AsyncEmailResource",
    "EmailResourceWithRawResponse",
    "AsyncEmailResourceWithRawResponse",
    "EmailResourceWithStreamingResponse",
    "AsyncEmailResourceWithStreamingResponse",
    "PreferencesResource",
    "AsyncPreferencesResource",
    "PreferencesResourceWithRawResponse",
    "AsyncPreferencesResourceWithRawResponse",
    "PreferencesResourceWithStreamingResponse",
    "AsyncPreferencesResourceWithStreamingResponse",
]
