# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["V3RetrievePapersByCountryParams"]


class V3RetrievePapersByCountryParams(TypedDict, total=False):
    country: str

    limit: str
